==> alg-alg-5.1.24-sources.jar: cn/com/duiba/nezha/alg/alg/vo/adx/directly/AdxIndexStatsDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.adx.directly;

public class AdxIndexStatsDo {

    /**
     * 出价（分/cpm）
     */
    private Long price;

    /**
     * 竞价量级
     */
    private Long bidCnt;

    /**
     * 竞价成功量级
     */
    private Long sucCnt;

    /**
     * 曝光量级
     */
    private Long expCnt;

    /**
     * 点击量级
     */
    private Long clickCnt;

    /**
     * adx消耗(分)
     */
    private Long adxConsume;

    /**
     * 广告消耗(分)
     */
    private Long advertConsume;

    /**
     * 数据是否置信
     */
    private Boolean isConfident;

    /**
     * 竞价成功率
     */
    private Double sucRate;

    /**
     * adx点击率
     */
    private Double ctr;

    /**
     * roi
     */
    private Double roi;

    /**
     * 每千次竞价收益
     */
    private Double rpm;

    /**
     * 广告发券数
     */
    private Long advertLaunch;

    /**
     * 广告计费点击数
     */
    private Long advertClick;

    /**
     * 预估点击价值总和
     */
    private Double preClickValueSum;

    /**
     * 实际点击价值（分/单次点击）
     */
    private Double clickValue;

    /**
     * 每PV发券(发券pv/adx点击PV)
     */
    private Double launchPv;

    /**
     * CPC(adx消耗/adx点击, 分/单次点击)
     */
    private Double cpc;


    public Long getPrice() {
        return price;
    }

    public void setPrice(Long price) {
        this.price = price;
    }

    public Long getBidCnt() {
        return bidCnt;
    }

    public void setBidCnt(Long bidCnt) {
        this.bidCnt = bidCnt;
    }

    public Long getSucCnt() {
        return sucCnt;
    }

    public void setSucCnt(Long sucCnt) {
        this.sucCnt = sucCnt;
    }

    public Long getExpCnt() {
        return expCnt;
    }

    public void setExpCnt(Long expCnt) {
        this.expCnt = expCnt;
    }

    public Long getClickCnt() {
        return clickCnt;
    }

    public void setClickCnt(Long clickCnt) {
        this.clickCnt = clickCnt;
    }

    public Long getAdxConsume() {
        return adxConsume;
    }

    public void setAdxConsume(Long adxConsume) {
        this.adxConsume = adxConsume;
    }

    public Long getAdvertConsume() {
        return advertConsume;
    }

    public void setAdvertConsume(Long advertConsume) {
        this.advertConsume = advertConsume;
    }

    public Boolean getConfident() {
        return isConfident;
    }

    public void setConfident(Boolean confident) {
        isConfident = confident;
    }

    public Double getSucRate() {
        return sucRate;
    }

    public void setSucRate(Double sucRate) {
        this.sucRate = sucRate;
    }

    public Double getCtr() {
        return ctr;
    }

    public void setCtr(Double ctr) {
        this.ctr = ctr;
    }

    public Double getRoi() {
        return roi;
    }

    public void setRoi(Double roi) {
        this.roi = roi;
    }

    public Double getRpm() {
        return rpm;
    }

    public void setRpm(Double rpm) {
        this.rpm = rpm;
    }

    public Long getAdvertLaunch() { return advertLaunch; }

    public void setAdvertLaunch(Long advertLaunch) { this.advertLaunch = advertLaunch; }

    public Long getAdvertClick() { return advertClick; }

    public void setAdvertClick(Long advertClick) { this.advertClick = advertClick; }

    public Double getPreClickValueSum() { return preClickValueSum; }

    public void setPreClickValueSum(Double preClickValueSum) { this.preClickValueSum = preClickValueSum; }

    public Double getClickValue() { return clickValue; }

    public void setClickValue(Double clickValue) { this.clickValue = clickValue; }

    public Double getLaunchPv() { return launchPv; }

    public void setLaunchPv(Double launchPv) { this.launchPv = launchPv; }

    public Double getCpc() { return cpc; }

    public void setCpc(Double cpc) { this.cpc = cpc; }
}

==> alg-alg-99.0.11-20201204.023308-2-sources.jar: cn/com/duiba/nezha/alg/alg/vo/adx/directly/AdxIndexStatsDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.adx.directly;

public class AdxIndexStatsDo {

    /**
     * 出价（分/cpm）
     */
    private Long price;

    /**
     * 竞价量级
     */
    private Long bidCnt;

    /**
     * 竞价成功量级
     */
    private Long sucCnt;

    /**
     * 曝光量级
     */
    private Long expCnt;

    /**
     * 点击量级
     */
    private Long clickCnt;

    /**
     * adx消耗(分)
     */
    private Long adxConsume;

    /**
     * 广告消耗(分)
     */
    private Long advertConsume;

    /**
     * 数据是否置信
     */
    private Boolean isConfident;

    /**
     * 竞价成功率
     */
    private Double sucRate;

    /**
     * adx点击率
     */
    private Double ctr;

    /**
     * roi
     */
    private Double roi;

    /**
     * 每千次竞价收益
     */
    private Double rpm;

    /**
     * 广告发券数
     */
    private Long advertLaunch;

    /**
     * 广告计费点击数
     */
    private Long advertClick;

    /**
     * 预估点击价值总和
     */
    private Double preClickValueSum;

    /**
     * 实际点击价值（分/单次点击）
     */
    private Double clickValue;

    /**
     * 每PV发券(发券pv/adx点击PV)
     */
    private Double launchPv;

    /**
     * CPC(adx消耗/adx点击, 分/单次点击)
     */
    private Double cpc;

    /**
     * 每PV点券(券计费点击PV/adx点击PV)
     */
    private Double chargePv;


    public Long getPrice() {
        return price;
    }

    public void setPrice(Long price) {
        this.price = price;
    }

    public Long getBidCnt() {
        return bidCnt;
    }

    public void setBidCnt(Long bidCnt) {
        this.bidCnt = bidCnt;
    }

    public Long getSucCnt() {
        return sucCnt;
    }

    public void setSucCnt(Long sucCnt) {
        this.sucCnt = sucCnt;
    }

    public Long getExpCnt() {
        return expCnt;
    }

    public void setExpCnt(Long expCnt) {
        this.expCnt = expCnt;
    }

    public Long getClickCnt() {
        return clickCnt;
    }

    public void setClickCnt(Long clickCnt) {
        this.clickCnt = clickCnt;
    }

    public Long getAdxConsume() {
        return adxConsume;
    }

    public void setAdxConsume(Long adxConsume) {
        this.adxConsume = adxConsume;
    }

    public Long getAdvertConsume() {
        return advertConsume;
    }

    public void setAdvertConsume(Long advertConsume) {
        this.advertConsume = advertConsume;
    }

    public Boolean getConfident() {
        return isConfident;
    }

    public void setConfident(Boolean confident) {
        isConfident = confident;
    }

    public Double getSucRate() {
        return sucRate;
    }

    public void setSucRate(Double sucRate) {
        this.sucRate = sucRate;
    }

    public Double getCtr() {
        return ctr;
    }

    public void setCtr(Double ctr) {
        this.ctr = ctr;
    }

    public Double getRoi() {
        return roi;
    }

    public void setRoi(Double roi) {
        this.roi = roi;
    }

    public Double getRpm() {
        return rpm;
    }

    public void setRpm(Double rpm) {
        this.rpm = rpm;
    }

    public Long getAdvertLaunch() { return advertLaunch; }

    public void setAdvertLaunch(Long advertLaunch) { this.advertLaunch = advertLaunch; }

    public Long getAdvertClick() { return advertClick; }

    public void setAdvertClick(Long advertClick) { this.advertClick = advertClick; }

    public Double getPreClickValueSum() { return preClickValueSum; }

    public void setPreClickValueSum(Double preClickValueSum) { this.preClickValueSum = preClickValueSum; }

    public Double getClickValue() { return clickValue; }

    public void setClickValue(Double clickValue) { this.clickValue = clickValue; }

    public Double getLaunchPv() { return launchPv; }

    public void setLaunchPv(Double launchPv) { this.launchPv = launchPv; }

    public Double getCpc() { return cpc; }

    public void setCpc(Double cpc) { this.cpc = cpc; }

    public Double getChargePv() { return chargePv; }

    public void setChargePv(Double chargePv) { this.chargePv = chargePv; }
}
